@@ -1,12 +1,14 @@
 import pygame
 import pymunk
+from win32api import GetSystemMetrics
 pygame.init()
 
 def nothing():
     pass
 class GameInstance:
-    def __init__(self,width,height):
-        self.win = pygame.display.set_mode((width,height))
+    def __init__(self):
+        self.win_size = (GetSystemMetrics(0), int(GetSystemMetrics(1)*0.9))
+        self.win = pygame.display.set_mode((self.win_size))
         self.clock = pygame.time.Clock()
         self.space = pymunk.Space()
 
